/**
 * BulkUploadSmttFilesController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.util.List;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.BulkUploadSmttFilesWorker;
import com.smartmatic.waffle.ecm.data.transfer.objects.FileToUploadDTO;
import com.smartmatic.waffle.ecm.service.lang.BulkDataLoadException.BulkDataLoadExceptionOperationExceptionInfo;

/**
 * Controller class that creates and starts the worker thread to execute the
 * bulk upload process of smartmatic files.
 */
public class BulkUploadSmttFilesController implements IAwtOperationListener {

	/**
	 * Instantiates a new BulkUploadSmttFilesController.
	 * 
	 * @param bulkUploadSmttFilesPanel
	 *            BulkUploadSmttFilesPanel instance
	 * @param smttFilesToUpĺoadList
	 *            Input list with files to load
	 * @param resourceFileContent
	 *            byte array with the resources file
	 */
	public BulkUploadSmttFilesController(
			BulkUploadSmttFilesPanel bulkUploadSmttFilesPanel,
			List<FileToUploadDTO> smttFilesToUpĺoadList,
			byte[] resourceFileContent) {

		this.bulkUploadSmttFilesPanel = bulkUploadSmttFilesPanel;
		this.smttFilesToUpĺoadList = smttFilesToUpĺoadList;
		this.resourceFileContent = resourceFileContent;
	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {

		this.bulkUploadSmttFilesWorker = new BulkUploadSmttFilesWorker(
				this.smttFilesToUpĺoadList, this.resourceFileContent);

		this.bulkUploadSmttFilesWorker.addListener(this);

		Thread bulkUploadSmttFilesWorkerThread = new Thread(
				this.bulkUploadSmttFilesWorker,
				"bulkUploadSmttFilesWorkerThread");

		bulkUploadSmttFilesWorkerThread.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener#awtOperation
	 * (com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType)
	 */
	@Override
	public void awtOperation(AwtOperationType awtOperationType) {

		switch (awtOperationType) {
		case UPDATE_COMPONENTS: {

			int amountOfProcessedFiles = this.bulkUploadSmttFilesWorker
					.getNumberOfProcessedFiles() + 1;

			String fileBeingProcessingName = this.bulkUploadSmttFilesWorker
					.getFileBeingProcessed();

			this.bulkUploadSmttFilesPanel
					.updateStatusDuringBulkUploadOperation(
							amountOfProcessedFiles,
							this.smttFilesToUpĺoadList.size(),
							fileBeingProcessingName);
		}

			break;

		case UPDATE_PROGRESS_BAR: {

			int amountOfProcessedFiles = this.bulkUploadSmttFilesWorker
					.getNumberOfProcessedFiles();

			this.bulkUploadSmttFilesPanel
					.updateProgressBar(amountOfProcessedFiles);

		}
			break;

		case SHOW_RESULT_MESSAGE: {
			this.bulkUploadSmttFilesPanel
					.finishBulkUploadProcess(this.bulkUploadSmttFilesWorker
							.getFileUploadedDetailList());
		}
			break;

		case SHOW_ERROR_MESSAGE: {
			showErrorMessageOperation();
		}
			break;

		case REPORT_ERROR_IN_PROCESS: {
			this.bulkUploadSmttFilesPanel
					.showErrorMessageBadlyConfiguredAudioVoting();
		}
			break;
		default:
			break;
		}

	}

	/**
	 * Method used to control the logic when an active worker fires the
	 * SHOW_ERROR_MESSAGE operation.
	 */
	private void showErrorMessageOperation() {

		if (this.bulkUploadSmttFilesWorker.bulkLoadExceptionInfo != null
				&& this.bulkUploadSmttFilesWorker.bulkLoadExceptionInfo
						.equals(BulkDataLoadExceptionOperationExceptionInfo.MISSING_REQUIRED_FIELDS_ERROR)) {
			this.bulkUploadSmttFilesPanel
					.showMissingRequiredFieldErrorMessageExecutingBulkUpload(this.bulkUploadSmttFilesWorker
							.getFileBeingProcessed());
		} else {
			this.bulkUploadSmttFilesPanel
					.showUnexpectedErrorMessageExecutingBulkUpload(this.bulkUploadSmttFilesWorker
							.getFileBeingProcessed());
		}
	}

	/** BulkUploadSmttFilesPanel instance. */
	private BulkUploadSmttFilesPanel bulkUploadSmttFilesPanel;

	/** Input list with files to load. */
	private List<FileToUploadDTO> smttFilesToUpĺoadList;

	/** Hold the byte array with the resources file. */
	private byte[] resourceFileContent;

	/** BulkUploadSmttFilesWorker instance. */
	private BulkUploadSmttFilesWorker bulkUploadSmttFilesWorker;
}
