/**
 * ManifestInfo.java
 *
 * $Revision: 1.2 $ ($Date: 2011-04-06 04:46:26 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.properties;

import java.io.File;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import java.util.jar.Attributes;
import java.util.jar.Attributes.Name;
import java.util.jar.JarFile;
import java.util.jar.Manifest;

/**
 * This utility class allows for manifest file inspection for any
 * web-application(.war), enterprise-application(.ear) or library(.jar).
 * 
 * @version 1.0 (2004.12.12)
 * @author Fernando Hernandez fhernandez@smartmatic.com
 */
public class ManifestInfo {

	/**
	 * Represents the manifest to be inspected.
	 */
	private Manifest mf;

	/**
	 * Application version of the manifest to be inspected.
	 */
	private String applicationVersion = "unknown";

	/**
	 * <p>
	 * All of the application/library to be inspected digests.
	 * </p>
	 * <p>
	 * The keys to this map are all names of all the modules found declared in
	 * the manifest. The values are their respective digests.
	 * </p>
	 */
	private Map<String, String> digests;

	/**
	 * Specific constructor, where any path and any filename can be specified,
	 * not the ones defined by default.
	 * 
	 * @param path
	 *            String the path of the application.
	 * @param fileName
	 *            String the name of the file where the application is.
	 */
	public ManifestInfo(String path, String fileName) {
		this.digests = new HashMap<String, String>();
		JarFile jarFile = null;
		// Load the file ear and jar file
		try {
			File earFile = new File(path, fileName);
			jarFile = new JarFile(earFile);
		} catch (Exception ex1) {
		}
		// Load the manifest
		try {
			this.mf = jarFile.getManifest();
			this.applicationVersion = this.mf.getMainAttributes()
					.get(Attributes.Name.SIGNATURE_VERSION).toString();
		} catch (Exception e) {
		}
		// Load the manifest entries
		try {
			Iterator<Entry<String, Attributes>> allAttIter = this.mf
					.getEntries().entrySet().iterator();
			while (allAttIter.hasNext()) {
				Entry<String, Attributes> key = allAttIter.next();
				Attributes attributes = key.getValue();
				String mapKey = key.getKey();
				for (Object password : attributes.keySet()) {
					if ("SHA1-Digest".equals(((Name) password).toString())) {
						String mapValue = attributes.getValue((Name) password);
						this.digests.put(mapKey, mapValue);
					}
				}
			}

		} catch (Exception e) {
		}
	}

	/**
	 * Getter of <code>applicationVersion</code> property.
	 * 
	 * @return <code>applicationVersion</code> property value.
	 * @see #applicationVersion
	 */
	public String getApplicationVersion() {
		return this.applicationVersion;
	}

	/**
	 * Getter of <code>digests</code> property.
	 * 
	 * @return <code>digests</code> property value.
	 * @see #digests
	 */
	public Map<String, String> getDigests() {
		return this.digests;
	}

}
