#
# File: FindGtkmm.cmake
#
# Date: Wed Apr 12 13:52:00 EST 2017
# Author: manuel.arguelles
#
# Copyright 2017 Smartmatic Corp. All Rights Reserved.
#
# Confidential Information of Smartmatic Labs. Not for disclosure or distribution
# prior written consent. This software contains code, techniques and know-how which
# is confidential and proprietary to Smartmatic.
#
# Use of this software is subject to the terms of an end user license agreement.
#
# Try to find gtkmm2 library
# Once done this will define
#
# GTKMM_FOUND        - True if gtkmm was found
# GTKMM_INCLUDE_DIRS - Location of gtkmm headers
# GTKMM_LIBRARIES    - List of ibraries to use gtkmm

INCLUDE (FindPackageHandleStandardArgs)

FIND_PACKAGE (PkgConfig QUIET)

PKG_CHECK_MODULES (PC_GTKMM QUIET gtkmm-2.4)

IF (PC_GTKMM_FOUND)
  SET (GTKMM_INCLUDE_DIRS ${PC_GTKMM_INCLUDE_DIRS})
ELSE ()
  SET (GTKMM_INCLUDE_DIRS "GTKMM_INCLUDE_DIRS-NOTFOUND")
ENDIF ()

SET (_FINAL_GTKMM_LIBS "")

FOREACH (_SUBLIB ${PC_GTKMM_LIBRARIES})
  FIND_LIBRARY (
    _TMP_FINAL_GTKMM_LIBS_${_SUBLIB}
    NAME ${_SUBLIB}
    HINTS ${PC_GTKMM_LIBDIR} ${PC_GTKMM_LIBRARY_DIRS}
    )
  IF (${_TMP_FINAL_GTKMM_LIBS_${_SUBLIB}} STREQUAL "_TMP_FINAL_GTKMM_LIBS_${_SUBLIB}-NOTFOUND")
    SET (_MISSING_LIBS TRUE)
  ELSE ()
    SET (_FINAL_GTKMM_LIBS ${_FINAL_GTKMM_LIBS} ${_TMP_FINAL_GTKMM_LIBS_${_SUBLIB}})
  ENDIF ()
ENDFOREACH ()

IF (_MISSING_LIBS OR _FINAL_GTKMM_LIBS STREQUAL "")
  SET (GTKMM_LIBRARIES "GTKMM_LIBRARIES-NOTFOUND")
ELSE ()
  SET (GTKMM_LIBRARIES "${_FINAL_GTKMM_LIBS}")
ENDIF ()

FIND_PACKAGE_HANDLE_STANDARD_ARGS (
  GTKMM
  REQUIRED_VARS GTKMM_LIBRARIES GTKMM_INCLUDE_DIRS
  VERSION_VAR PC_GTKMM_VERSION
  )

MARK_AS_ADVANCED (GTKMM_LIBRARIES GTKMM_INCLUDE_DIRS)
