#
# UnitTests support with CppUnit
# To use: INCLUDE(UnitTests)
#
# Date: Fri Feb 17 12:00:00 EST 2017
# Author: gustavo.garcia
#===================================================================
# Macros:
# UNITTESTS_RUN_SINGLE_TEST (_testSuiteFile _libToTest)
# UNITTESTS_RUN_ALL_TESTS (_libToTest _testSuiteFiles)
#-------------------------------------------------------------------

FIND_PACKAGE (CppUnit    REQUIRED)
FIND_PACKAGE (Mockpp     REQUIRED)
FIND_PACKAGE (NuanceVE   REQUIRED)

INCLUDE_DIRECTORIES (${CMAKE_CURRENT_SOURCE_DIR})
INCLUDE_DIRECTORIES (${CMAKE_CURRENT_SOURCE_DIR}/tests)
INCLUDE_DIRECTORIES (SYSTEM ${CPPUNIT_INCLUDE_DIRS})
INCLUDE_DIRECTORIES (SYSTEM ${LIBMOCKPP_INCLUDE_DIRS})

SET (CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -DECUT_MAIN")
IF (NOT TARGET check)
  ADD_CUSTOM_TARGET(check)
ENDIF ()
FILE (GLOB_RECURSE TESTS_MAIN_FILE tests/MainTest.cpp)

MACRO (UNITTESTS_RUN_SINGLE_TEST _testSuiteFile _libToTest)

  FILE (GLOB_RECURSE TESTSUITE_FULL_PATH ${_testSuiteFile})
  SET (PROJECT_TEST_NAME test-${_libToTest})
  ADD_EXECUTABLE (${PROJECT_TEST_NAME} EXCLUDE_FROM_ALL ${TESTS_MAIN_FILE} ${TESTSUITE_FULL_PATH})
  TARGET_LINK_LIBRARIES (${PROJECT_TEST_NAME} ${LIB_OUTPUT_NAME} ${CPPUNIT_LIBRARIES} ${LIBMOCKPP_LIBRARY} ${NUANCEVE_LIBRARIES})
  ADD_DEPENDENCIES(check ${PROJECT_TEST_NAME})
  ADD_CUSTOM_COMMAND(
  TARGET check
  COMMENT "Run TestSuite"
  POST_BUILD COMMAND ./${PROJECT_TEST_NAME}
  )
ENDMACRO ()

MACRO (UNITTESTS_RUN_ALL_TESTS _libToTest _testSuiteFiles)
  SET (PROJECT_TEST_NAME test-${_libToTest})
  SET (i 0)
  FOREACH (file ${_testSuiteFiles} ${ARGN})
    IF (NOT ${file} STREQUAL ${TESTS_MAIN_FILE})
      SET(SINGLE_TEST ${file} ${TESTS_MAIN_FILE})

      ADD_CUSTOM_TARGET (${PROJECT_TEST_NAME}_TestSuite${i})
      ADD_EXECUTABLE (${PROJECT_TEST_NAME}-${i} EXCLUDE_FROM_ALL ${SINGLE_TEST})
      TARGET_LINK_LIBRARIES (${PROJECT_TEST_NAME}-${i} ${LIB_OUTPUT_NAME} ${CPPUNIT_LIBRARIES} ${LIBMOCKPP_LIBRARY} ${NUANCEVE_LIBRARIES})
      ADD_DEPENDENCIES (${PROJECT_TEST_NAME}_TestSuite${i} ${PROJECT_TEST_NAME}-${i})

      SET (CHECK_DEPENDENCIES ${CHECK_DEPENDENCIES} ${PROJECT_TEST_NAME}-${i})
      ADD_DEPENDENCIES (check ${PROJECT_TEST_NAME}-${i})
      ADD_DEFINITIONS(-DMOCKPP_ENABLE_DEFAULT_FORMATTER)

      IF (DEFINED CMAKE_RUNTIME_OUTPUT_DIRECTORY)
	ADD_CUSTOM_COMMAND (
          TARGET ${PROJECT_TEST_NAME}-${i}
          COMMENT "Run ${PROJECT_TEST_NAME}_TestSuite${i}"
	  POST_BUILD COMMAND ${CMAKE_RUNTIME_OUTPUT_DIRECTORY}/${PROJECT_TEST_NAME}-${i}
	  )
      ELSE ()
	ADD_CUSTOM_COMMAND (
          TARGET ${PROJECT_TEST_NAME}-${i}
          COMMENT "Run ${PROJECT_TEST_NAME}_TestSuite${i}"
          POST_BUILD COMMAND ./${PROJECT_TEST_NAME}-${i}
	  )
      ENDIF ()
      MATH (EXPR i "${i} + 1")
    ENDIF ()
  ENDFOREACH ()
ENDMACRO ()


