/*
 * BeforeGeneratingResultsComplianceVerificator.cxx
 *
 *  Created on: Feb 14, 2018
 *      Author: eduardo.fernandez
 */

#include "BeforeGeneratingResultsComplianceVerificator.hxx"

#include "VoteComplianceVerificationManager.hxx"
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Log/SMTTLogManager.h>
#include <Voting/ElectoralConfiguration.hxx>
#include <Resources/election-string-resources-manager.h>
#include <Voting/Vote/vote-schema.hxx>
#include <Voting/Election/election-schema.hxx>

#ifdef HAVE_CONFIG_H
#include "../../config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::SAES::Operation::VoteCompliance;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Voting::PBReports;
using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;

ISMTTLog * BeforeGeneratingResultsComplianceVerificator::m_logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Voting.BeforeGeneratingResultsComplianceVerificator", GETTEXT_PACKAGE );

BeforeGeneratingResultsComplianceVerificator::BeforeGeneratingResultsComplianceVerificator (ElectoralConfiguration *electoralConfiguration)
: m_voteComplianceVerificationManager(new VoteComplianceVerificationManager(electoralConfiguration))
{
}

BeforeGeneratingResultsComplianceVerificator::~BeforeGeneratingResultsComplianceVerificator()
{
}

bool BeforeGeneratingResultsComplianceVerificator::checkTotalCumulativeSelections(const size_t totalVotes, const VoteResults &voteResults)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforeGeneratingResultsComplianceVerificationConfiguration().getCheckTotalCumulativeSelections())
    {
        success = m_voteComplianceVerificationManager->checkTotalCumulativeSelections(totalVotes, voteResults);
    }

    return success;
}

bool BeforeGeneratingResultsComplianceVerificator::checkIndividualCumulativeSelections(const VoteResults &voteResults)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforeGeneratingResultsComplianceVerificationConfiguration().getCheckIndividualCumulativeSelections())
    {
        success = m_voteComplianceVerificationManager->checkIndividualCumulativeSelections(voteResults);
    }

    return success;
}
