/**
 * @file	close-election-functionality.h
 * @brief	Declares the close election functionality class.
 * @author	Gustavo Garcia
 * @date	31/01/2017
 */

#ifndef _CLOSE_ELECTION_FUNCTIONALITY_H_


#define _CLOSE_ELECTION_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Widgets/wizard-widget-manager.h>
#include <Widgets/wizard-widget-base.h>
#include "Gui/Widgets/close-election-status-widget.h"
#include "Gui/Widgets/ExternalPrintWidget.hxx"
#include "Gui/Widgets/close-election-confirmation-widget.h"
#include "Gui/Widgets/PersistAllResultWidget.hxx"
#include "Gui/Widgets/ValidateEmlSignatureWidget.hxx"
#include "Gui/Widgets/ValidateVotesWidget.hxx"
#include <Gui/Widgets/Transmission/ResultsPackageTransmissionWidget.hxx>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	CloseElectionFunctionality
                 * @brief	Close election functionality.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class CloseElectionFunctionality: public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	static CloseElectionFunctionality * CloseElectionFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else.
                         */

                        static CloseElectionFunctionality * getInstance();

                        /**
                         * @fn	virtual void CloseElectionFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();

                    protected:

                        /**
                         * @fn	void CloseElectionFunctionality::on_cancelButton_clicked();
                         * @brief	Handles cancel button clicked signal.
                         * @author	Juan.Delgado
                         * @date	30/06/2011
                         */
                        void on_cancelButton_clicked();

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * CloseElectionFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring CloseElectionFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring CloseElectionFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The finish log message.
                         */

                        Glib::ustring getFinishLogMessage();

                    private:
                        /**
                         * @fn	void CloseElectionFunctionality::HideOnFinish();
                         * @brief	Hides the on finish.
                         * @author	Juan Valera
                         * @date	03/03/2017
                         */
                        void HideOnFinish();
                        /**
                         * @fn	void CloseElectionFunctionality::ErrorHappen();
                         * @brief	Error happen.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void ErrorHappen();

                        Smartmatic::SAES::GUI::Widgets::CloseElectionStatusWidget * closeStatus;	///< The close status
                        Smartmatic::SAES::GUI::Widgets::ExternalPrintWidget * externalPrintWidget;      ///< The external print widget
                        Smartmatic::SAES::GUI::Widgets::CloseElectionConfirmationWidget * closeConfirmation;	///< The close confirmation
                        Smartmatic::SAES::GUI::Widgets::PersistAllResultWidget * persistAllResultWidget; ///<widget persist all result files
                        Smartmatic::SAES::GUI::Widgets::ValidateEmlSignatureWidget * validateSignatureWidget; ///<widget validate signature eml files
                        Smartmatic::SAES::GUI::Widgets::ValidateVotesWidget * validateVotesWidget; ///< validate votes
                        Smartmatic::SAES::GUI::Widgets::ResultsPackageTransmissionWidget * resultsPackageTransmissionWidget; ///< Send results package widget
                        Smartmatic::GUI::Widgets::WizardWidgetManager * manager;	///< The manager

                        int count; ///< count state

                        /**
                         * @fn	void CloseElectionFunctionality::ElectionWasClosed();
                         * @brief	Sets the label in election was closed.
                         * @author	Juan.Delgado
                         * @date	15/08/2011
                         */

                        void ElectionWasClosed();

                        /**
                         * @fn	void CloseElectionFunctionality::TransitionSignal();
                         * @brief	Transition signal.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */
                        void TransitionSignal();

                        static CloseElectionFunctionality * current_instance; ///< The current instance

                        /**
                         * @fn	CloseElectionFunctionality::CloseElectionFunctionality();
                         * @brief	Default constructor.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        CloseElectionFunctionality();

                        /**
                         * @fn	virtual CloseElectionFunctionality::~CloseElectionFunctionality();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~CloseElectionFunctionality();

                        /**
                         * @fn	void CloseElectionFunctionality::on_close_clicked();
                         * @brief	Handles close clicked signals.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void on_close_clicked();

                        /**
                         * @fn	void CloseElectionFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Dispose();

                        /**
                         * @fn	void CloseElectionFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Initialize();

                        /**
                         * @fn	Gtk::Widget * CloseElectionFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	std::string CloseElectionFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType CloseElectionFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @fn	void CloseElectionFunctionality::LoadWizardFrame();
                         * @brief	Load the Wizard Frame.
                         * @author	Juan.Delgado
                         * @date	30/06/2011
                         */
                        void LoadWizardFrame();

                        /**
                         * @fn	void endWizardMamager ();
                         * @brief	Callback end signal the wizard.
                         * @author	Yadickson Soto
                         * @date	07/02/2014
                         */
                        void endWizardMamager ();

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                        std::vector<Smartmatic::GUI::Widgets::WizardWidgetBase *> wizardVector; ///< The wizard vector

                        int countGeneratePV; ///< count pv
                        int countGenerateAllResult; ///< count all result
                        bool generatePV; ///< flag step printer pv
                };
            }
        }
    }
}

#endif // _CLOSE_ELECTION_FUNCTIONALITY_H_
