/**
 * @file   ExternalPrintWidget.cxx
 * @brief  Implementation of ExternalPrintWidget.
 * @author manuel.arguelles
 * @date   Jun  9, 2017
 */

#include "ExternalPrintWidget.hxx"
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Gui/Widgets/ExternalPrintWizardWidget.hxx>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "../../config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String)
#else
#define _(String) (String)
#endif

#define N_(String) (String)

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Widgets;

static ISMTTLog* logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.GUI.Widgets.ExternalPrintWidget",
    GETTEXT_PACKAGE);

ExternalPrintWidget::ExternalPrintWidget()
{
    logger->Debug("Smartmatic::SAES::GUI::Widgets::ExternalPrintWidget");

    m_wizardWidget = AbstractFactoryWidget::createExternalPrintWizardWidget();
    m_wizardWidget->getFinishSignal().connect(sigc::mem_fun(
                                                  *this,
                                                  &ExternalPrintWidget::onWizardDone));
    setWidget(m_wizardWidget);
}

ExternalPrintWidget::~ExternalPrintWidget()
{
    remove();
    delete m_wizardWidget;
}

void ExternalPrintWidget::initialize()
{
    m_disable_close_signal.emit();
    m_wizardWidget->Initialize();
}

void ExternalPrintWidget::onWizardDone()
{
    on_stop_signal_emit().emit();
}
