/**
 * @file	voting-widget-base.cc
 * @brief	voting widget base class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "voting-widget-base.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include "Environment/Configurations/resource-path-provider.h"
#include "Configuration/label-configuration.h"
#include "Configuration/SaesGUIConfiguration-schema.hxx"

#ifdef HAVE_CONFIG_H
#include "../../config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::GUI::Operation;
using namespace Smartmatic::GUI::Widgets;

VotingWidgetBase::VotingWidgetBase ( Smartmatic::SAES::Configuration::WidgetDisplayType & display, std::string displayString, std::string number, int padding, int numberWidth, int width, int height, bool showNumberA, bool isReferendum )
{
    this->numberWidth = numberWidth;
    this->number = number;
    this->display = display;
    this->padding = padding;
    this->displayString = displayString;
    this->topString = "";
    this->bottomString = "";
    this->showNumber = showNumberA;
    this->isReferendum = isReferendum;
    Initialize ( width, height );
}

VotingWidgetBase::VotingWidgetBase ( Smartmatic::SAES::Configuration::WidgetDisplayType & display, std::string displayString, std::string number, int padding, int numberWidth,
                                     Smartmatic::GUI::Configuration::LabelConfiguration labelChildConfigurationA, int width, int height, bool showNumberA )
{
    this->numberWidth = numberWidth;
    this->number = number;
    this->display = display;
    this->padding = padding;
    this->displayString = displayString;
    this->topString = "";
    this->bottomString = "";
    this->showNumber = showNumberA;
    this->isReferendum = false;
    Initialize ( width, height );
}

VotingWidgetBase::VotingWidgetBase ( std::string topString, std::string bottomString, std::string number, int padding, int numberWidth, int width, int height, bool showNumberA )
{
    this->numberWidth = numberWidth;
    this->number = number;
    this->display = WidgetDisplayType ( DisplayType::CONFIGURATION_DUAL_TEXT, 0, 0 );
    this->padding = padding;
    this->displayString = "";
    this->topString = topString;
    this->bottomString = bottomString;
    this->showNumber = showNumberA;
    this->isReferendum = false;
    Initialize ( width, height );
}

VotingWidgetBase::~VotingWidgetBase()
{
    if ( image_child )
    {
        delete image_child;
    }

    if ( label_child )
    {
        delete label_child;
    }

    if ( top_child )
    {
        delete top_child;
    }

    if ( bottom_child )
    {
        delete bottom_child;
    }

    if ( number_child )
    {
        delete number_child;
    }

    image_child = 0;
    label_child = 0;
    top_child = 0;
    bottom_child = 0;
    number_child = 0;
}

void VotingWidgetBase::Initialize ( int width, int height )
{
    static LabelConfiguration labelChildConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetLabelChildLabelConfiguration();
    static LabelConfiguration topChildConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetTopChildLabelConfiguration();
    static LabelConfiguration bottomChildConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetBottomChildLabelConfiguration();
    static LabelConfiguration numberChildConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetNumberChildLabelConfiguration();
    static LabelConfiguration referendumConfiguration = SAESGUIConfigurationManager::getInstance()->GetReferendumBallotsLabelConfiguration();
    image_child = 0;
    label_child = 0;
    top_child = 0;
    bottom_child = 0;
    number_child = 0;
    sizeAllocateCallback = false;
    set_flags ( Gtk::NO_WINDOW );
    set_redraw_on_allocate ( false );
    static Smartmatic::SAES::Configuration::BallotOptionWidgetConfiguration config =
        Smartmatic::SAES::GUI::Configuration::SAESGUIConfigurationManager::getInstance()->GetBallotOptionWidgetConfiguration();

    switch ( display.getType() )
    {
        case DisplayType::CONFIGURATION_TEXT:
            {
                label_child = new SmartmaticBasicLabel ( displayString );
                label_child->set_line_wrap ( true );
                label_child->set_parent ( *this );
                label_child->set_alignment ( display.getXAlign(), display.getYAlign() );
                label_child->show();
                label_child->setAccessibleName ( "VotingWidgetBaseText" );

                if ( !isReferendum )
                {
                    Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfigurationWithoutAlignment ( label_child, labelChildConfiguration );
                }
                else
                {
                    Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfigurationWithoutAlignment ( label_child, referendumConfiguration );
                }
            }
            break;

        case DisplayType::CONFIGURATION_DUAL_TEXT:
            {
                top_child = new SmartmaticBasicLabel ( topString );
                top_child->set_line_wrap ( false );
                top_child->set_parent ( *this );
                top_child->set_alignment ( display.getXAlign(), display.getYAlign() );
                Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfigurationWithoutAlignment ( top_child, topChildConfiguration );
                top_child->show();
                top_child->setAccessibleName ( "VotingWidgetBaseTopText" );

                if ( !bottomString.empty() )
                {
                    bottom_child = new SmartmaticBasicLabel ( bottomString );
                    bottom_child->set_line_wrap ( false );
                    bottom_child->set_parent ( *this );
                    bottom_child->set_alignment ( display.getXAlign(), display.getYAlign() );
                    Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfigurationWithoutAlignment ( bottom_child, bottomChildConfiguration );
                    bottom_child->show();
                    bottom_child->setAccessibleName ( "VotingWidgetBaseBottomText" );
                }
            }
            break;

        case DisplayType::CONFIGURATION_IMAGE_FULL:
        case DisplayType::CONFIGURATION_IMAGE_FIX:
        case DisplayType::CONFIGURATION_IMAGE_RESIZE:
            {
                image_child = new SmartmaticBasicImage();
                image_child->set_parent ( *this );
                image_child->set_alignment ( display.getXAlign(), display.getYAlign() );
                image_child->clear();
                image_child->set ( displayString );
                image_child->show();
                image_child->setAccessibleName ( "VotingWidgetBaseImage" );
            }
            break;

        default:
            break;
    }

    if ( this->showNumber )
    {
        number_child = new SmartmaticBasicLabel ( number );
        number_child->set_line_wrap ( true );
        number_child->set_parent ( *this );
        number_child->set_alignment ( 0, 0 );
        Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfigurationWithoutAlignment ( number_child, numberChildConfiguration );
        number_child->show();
        number_child->setAccessibleName ( "VotingWidgetBaseNumber" );
    }

    setSize ( width, height );
    show();
}

void VotingWidgetBase::setSize ( int width, int height )
{
    set_size_request ( width, height );

    switch ( display.getType() )
    {
        case DisplayType::CONFIGURATION_TEXT:
            {
                int innerNumberWidth = 	showNumber ? numberWidth : 0;
                label_child->set_size_request ( width - padding - innerNumberWidth, height - 2 * padding );
                break;
            }

        case DisplayType::CONFIGURATION_DUAL_TEXT:
            {
                if ( bottomString.empty() )
                {
                    int innerNumberWidth = 	showNumber ? numberWidth : 0;
                    top_child->set_size_request ( width - padding - innerNumberWidth, height - 2 * padding );
                }
            }
            break;

        case DisplayType::CONFIGURATION_IMAGE_FULL:
        case DisplayType::CONFIGURATION_IMAGE_FIX:
        case DisplayType::CONFIGURATION_IMAGE_RESIZE:
        default:
            break;
    }
}

void VotingWidgetBase::on_size_allocate ( Gtk::Allocation & allocation )
{
    if ( !sizeAllocateCallback )
    {
        set_allocation ( allocation );
        Gtk::Allocation child_allocation;
        int innerNumberWidth = 	this->showNumber ? numberWidth : 0;
        int width = allocation.get_width() - innerNumberWidth;
        int height = allocation.get_height();
        float position_x ( 0.0 ), position_y ( 0.0 );
        Pango::Rectangle rec, dummy;
        Glib::RefPtr<Pango::Layout> layout;

        switch ( display.getType() )
        {
            case DisplayType::CONFIGURATION_TEXT:
                {
                    if ( label_child )
                    {
                        layout = label_child->get_layout();
                        layout->get_pixel_extents ( dummy, rec );
                        child_allocation.set_width ( width - padding );
                        child_allocation.set_height ( height - 2 * padding );
                        int originalSizeFont = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetLabelChildLabelConfiguration().GetSize();
                        int delta ( 10 );

                        while ( ( unsigned ) rec.get_width() > ( unsigned ) ( width - padding - delta ) )
                        {
                            originalSizeFont--;
                            Pango::FontDescription fontTitle = label_child->get_style()->get_font();
                            fontTitle.set_size ( originalSizeFont * Pango::SCALE );
                            label_child->modify_font ( fontTitle );
                            layout = label_child->get_layout();
                            layout->get_pixel_extents ( dummy, rec );
                        }

                        if ( !isReferendum )
                        {
                            static Smartmatic::GUI::Configuration::LabelAlignmentEnum labelAlignment =
                                SAESGUIConfigurationManager::getInstance()->GetVotingWidgetLabelChildLabelConfiguration().GetLabelAlignment();

                            switch ( labelAlignment )
                            {
                                case Smartmatic::GUI::Configuration::LeftAlignment:
                                    position_x = allocation.get_x() + innerNumberWidth;
                                    break;

                                case Smartmatic::GUI::Configuration::CenterAlignment:
                                    position_x = allocation.get_x() + innerNumberWidth + width / 2 - rec.get_width() / 2;
                                    break;

                                case Smartmatic::GUI::Configuration::RigthAlignment:
                                    position_x = allocation.get_x() + innerNumberWidth + width - padding - rec.get_width();
                                    break;

                                default:
                                    break;
                            }
                        }
                        else
                        {
                            static Smartmatic::GUI::Configuration::LabelAlignmentEnum labelAlignment =
                                SAESGUIConfigurationManager::getInstance()->GetReferendumBallotsLabelConfiguration().GetLabelAlignment();

                            switch ( labelAlignment )
                            {
                                case Smartmatic::GUI::Configuration::LeftAlignment:
                                    position_x = allocation.get_x() + innerNumberWidth;
                                    break;

                                case Smartmatic::GUI::Configuration::CenterAlignment:
                                    position_x = allocation.get_x() + innerNumberWidth + width / 2 - rec.get_width() / 2;
                                    break;

                                case Smartmatic::GUI::Configuration::RigthAlignment:
                                    position_x = allocation.get_x() + innerNumberWidth + width - padding - rec.get_width();
                                    break;

                                default:
                                    break;
                            }
                        }

                        position_y = allocation.get_y() + ( height / 2 ) - ( ( rec.get_height() / 2 ) );
                        child_allocation.set_x ( position_x );
                        child_allocation.set_y ( position_y );
                        label_child->size_allocate ( child_allocation );
                    }
                }
                break;

            case DisplayType::CONFIGURATION_DUAL_TEXT:
                {
                    if ( top_child && bottom_child )
                    {
                        //label top
                        layout = top_child->get_layout();
                        layout->get_pixel_extents ( dummy, rec );
                        child_allocation.set_width ( width - padding );
                        child_allocation.set_height ( height / 2 - padding );
                        static LabelConfiguration topChildConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetTopChildLabelConfiguration();

                        switch ( topChildConfiguration.GetLabelAlignment() ) //top
                        {
                            case Smartmatic::GUI::Configuration::LeftAlignment:
                                position_x = allocation.get_x() + innerNumberWidth;
                                break;

                            case Smartmatic::GUI::Configuration::CenterAlignment:
                                position_x = allocation.get_x() + innerNumberWidth + width / 2 - rec.get_width() / 2;
                                break;

                            case Smartmatic::GUI::Configuration::RigthAlignment:
                                position_x = allocation.get_x() + innerNumberWidth + width - padding - rec.get_width();
                                break;

                            default:
                                break;
                        }

                        //TODO size of text
                        child_allocation.set_x ( position_x );
                        child_allocation.set_y ( allocation.get_y() + padding );
                        top_child->size_allocate ( child_allocation );
                        //label bottom
                        layout = bottom_child->get_layout();
                        layout->get_pixel_extents ( dummy, rec );
                        child_allocation.set_width ( width - padding );
                        child_allocation.set_height ( height / 2 - padding );
                        static LabelConfiguration bottomChildConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetBottomChildLabelConfiguration();

                        switch ( bottomChildConfiguration.GetLabelAlignment() ) //bottom
                        {
                            case Smartmatic::GUI::Configuration::LeftAlignment:
                                position_x = allocation.get_x() + innerNumberWidth;
                                break;

                            case Smartmatic::GUI::Configuration::CenterAlignment:
                                position_x = allocation.get_x() + innerNumberWidth + width / 2 - rec.get_width() / 2;
                                break;

                            case Smartmatic::GUI::Configuration::RigthAlignment:
                                position_x = allocation.get_x() + innerNumberWidth + width - padding - rec.get_width();
                                break;

                            default:
                                break;
                        }

                        child_allocation.set_x ( position_x );
                        child_allocation.set_y ( allocation.get_y() + height - padding - rec.get_height() );
                        bottom_child->size_allocate ( child_allocation );
                    }
                    else if ( top_child )
                    {
                        layout = top_child->get_layout();
                        layout->get_pixel_extents ( dummy, rec );
                        child_allocation.set_width ( width - padding );
                        child_allocation.set_height ( height - 2 * padding );
                        int originalSizeFont = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetTopChildLabelConfiguration().GetSize();

                        while ( rec.get_width() > width - padding )
                        {
                            originalSizeFont--;
                            Pango::FontDescription fontTitle = top_child->get_style()->get_font();
                            fontTitle.set_size ( originalSizeFont * Pango::SCALE );
                            top_child->modify_font ( fontTitle );
                            layout = top_child->get_layout();
                            layout->get_pixel_extents ( dummy, rec );
                        }

                        static Smartmatic::GUI::Configuration::LabelAlignmentEnum labelAlignment =
                            SAESGUIConfigurationManager::getInstance()->GetReferendumBallotsLabelConfiguration().GetLabelAlignment();

                        switch ( labelAlignment )
                        {
                            case Smartmatic::GUI::Configuration::LeftAlignment:
                                position_x = allocation.get_x() + innerNumberWidth;
                                break;

                            case Smartmatic::GUI::Configuration::CenterAlignment:
                                position_x = allocation.get_x() + innerNumberWidth + width / 2 - rec.get_width() / 2;
                                break;

                            case Smartmatic::GUI::Configuration::RigthAlignment:
                                position_x = allocation.get_x() + innerNumberWidth + width - padding - rec.get_width();
                                break;

                            default:
                                break;
                        }

                        position_y = allocation.get_y() + ( height / 2 ) - ( ( rec.get_height() / 2 ) );
                        child_allocation.set_x ( position_x );
                        child_allocation.set_y ( position_y );
                        top_child->size_allocate ( child_allocation );
                    }
                }
                break;

            case DisplayType::CONFIGURATION_IMAGE_FIX:
                {
                    if ( image_child )
                    {
                        //image
                        child_allocation.set_width ( width - padding );
                        child_allocation.set_height ( height -  2 * padding );
                        child_allocation.set_x ( allocation.get_x() + innerNumberWidth );
                        child_allocation.set_y ( allocation.get_y() + padding );
                        image_child->size_allocate ( child_allocation );

                        double w = ( display.getWidth().present() ? display.getWidth().get() : child_allocation.get_width() );
                        double h = ( display.getHeight().present() ? display.getHeight().get() : child_allocation.get_height() );

                        Glib::RefPtr<Gdk::Pixbuf> tempPixbuf = image_child->get_pixbuf();
                        tempPixbuf = tempPixbuf->scale_simple ( w, h, Gdk::INTERP_HYPER );
                        image_child->set ( tempPixbuf );
                    }
                }
                break;

            case DisplayType::CONFIGURATION_IMAGE_FULL:
                {
                    if ( image_child )
                    {
                        //image
                        child_allocation.set_width ( width - padding );
                        child_allocation.set_height ( height -  2 * padding );
                        child_allocation.set_x ( allocation.get_x() + innerNumberWidth );
                        child_allocation.set_y ( allocation.get_y() + padding );
                        image_child->size_allocate ( child_allocation );

                        Glib::RefPtr<Gdk::Pixbuf> tempPixbuf = image_child->get_pixbuf();
                        tempPixbuf = tempPixbuf->scale_simple ( child_allocation.get_width(), child_allocation.get_height(), Gdk::INTERP_HYPER );
                        image_child->set ( tempPixbuf );
                    }
                }
                break;

            case DisplayType::CONFIGURATION_IMAGE_RESIZE:
                {
                    if ( image_child )
                    {
                        //image
                        child_allocation.set_width ( width - padding );
                        child_allocation.set_height ( height -  2 * padding );
                        child_allocation.set_x ( allocation.get_x() + innerNumberWidth );
                        child_allocation.set_y ( allocation.get_y() + padding );
                        image_child->size_allocate ( child_allocation );

                        double w = ( display.getWidth().present() ? display.getWidth().get() : child_allocation.get_width() );
                        double h = ( display.getHeight().present() ? display.getHeight().get() : child_allocation.get_height() );

                        if ( w > child_allocation.get_width() )
                        {
                            w = child_allocation.get_width();
                        }

                        if ( h > child_allocation.get_height() )
                        {
                            h = child_allocation.get_height();
                        }

                        Glib::RefPtr<Gdk::Pixbuf> tempPixbuf = image_child->get_pixbuf();
                        double ri = ( double ) tempPixbuf->get_height() / ( double ) tempPixbuf->get_width();

                        double nw = h / ri;
                        double nh = ri * nw;

                        if ( nw > w )
                        {
                            nw = w;
                            nh = ri * nw;
                        }

                        tempPixbuf = tempPixbuf->scale_simple ( nw, nh, Gdk::INTERP_HYPER );
                        //
                        image_child->set ( tempPixbuf );
                    }
                }
                break;

            default:
                break;
        }

        //number
        if ( this->showNumber )
        {
            layout = number_child->get_layout();
            layout->get_pixel_extents ( dummy, rec );
            position_x = allocation.get_x() + innerNumberWidth / 2 - rec.get_width() / 2;
            position_y = allocation.get_y() + height / 2  - rec.get_height() / 2;

            if ( position_x < allocation.get_x() + padding )
            {
                position_x = allocation.get_x() + padding;
            }

            if ( position_y < allocation.get_y() + padding )
            {
                position_y = allocation.get_y() + padding;
            }

            child_allocation.set_width ( innerNumberWidth - padding );
            child_allocation.set_height ( height - 2 * padding );
            child_allocation.set_x ( position_x );
            child_allocation.set_y ( position_y );
            number_child->size_allocate ( child_allocation );
        }

        sizeAllocateCallback = true;
    }
}

void VotingWidgetBase::forall_vfunc ( gboolean include_internals, GtkCallback callback, gpointer callback_data )
{
    if ( image_child )
    {
        callback ( GTK_WIDGET ( image_child->gobj() ), callback_data );
    }

    if ( label_child )
    {
        callback ( GTK_WIDGET ( label_child->gobj() ), callback_data );
    }

    if ( top_child )
    {
        callback ( GTK_WIDGET ( top_child->gobj() ), callback_data );
    }

    if ( bottom_child )
    {
        callback ( GTK_WIDGET ( bottom_child->gobj() ), callback_data );
    }

    if ( number_child )
    {
        callback ( GTK_WIDGET ( number_child->gobj() ), callback_data );
    }
}

void VotingWidgetBase::on_add ( Gtk::Widget * child )
{
    //No more widgets can be added.
}

void VotingWidgetBase::on_remove ( Gtk::Widget * child )
{
    if ( image_child )
    {
        image_child->unparent();
    }

    if ( label_child )
    {
        label_child->unparent();
    }

    if ( top_child )
    {
        top_child->unparent();
    }

    if ( bottom_child )
    {
        bottom_child->unparent();
    }

    if ( number_child )
    {
        number_child->unparent();
    }
}

GType VotingWidgetBase::child_type_vfunc() const
{
    //No more widgets can be added.
    return G_TYPE_NONE;
}

void VotingWidgetBase::refreshLabel ( std::string text )
{
    if ( label_child )
    {
        label_child->set_text ( text );
    }
}
