#!/bin/bash
#
# File: create-eclipse-project.sh
#
# Create a project file for import in eclipse IDE.
#
# Date: Mon Apr 10, 10:23:00 EST 2017.
# Author: manuel.arguelles
#
# Revision: 1
#
# Copyright 2017 Smartmatic Corp. All Rights Reserved.
#
# Confidential Information of Smartmatic Labs. Not for disclosure or distribution
# prior written consent. This software contains code, techniques and know-how which
# is confidential and proprietary to Smartmatic.
#
# Use of this software is subject to the terms of an end user license agreement.
#

SOURCE_DIR=$PWD
CMAKE_OPTIONS="-DCMAKE_BUILD_TYPE=Debug -DCMAKE_INSTALL_PREFIX=/usr"

if [ ! -f "$SOURCE_DIR/CMakeLists.txt" ]; then
    echo 'Please run this script from the source (parent) directory'
    exit
fi

rm -rf "$SOURCE_DIR/build/CMakeCache.txt" "$SOURCE_DIR/build/CMakeFiles"
cmake -G "Eclipse CDT4 - Unix Makefiles" ${CMAKE_OPTIONS} -B"${SOURCE_DIR}/build" -H${SOURCE_DIR}

mv "${SOURCE_DIR}/build/.cproject" "${SOURCE_DIR}"
sed s:\"obj:\"build/obj:g "${SOURCE_DIR}/.cproject" -i
sed s:/usr/bin/make:cmake:g "${SOURCE_DIR}/.cproject" -i
sed s:"-j4":"--build build --target":g "${SOURCE_DIR}/.cproject" -i

mv "${SOURCE_DIR}/build/.project" "${SOURCE_DIR}"
sed s:/build\<:\<:g "${SOURCE_DIR}/.project" -i
sed s:/usr/bin/make:cmake:g "${SOURCE_DIR}/.project" -i
sed s:"-j4":"--build build --target":g "${SOURCE_DIR}/.project" -i

echo
echo "Import the project from Eclipse IDE"
echo "   1. Import project using Menu File->Import"
echo "   2. Select General->Existing projects into workspace:"
echo "   3. Browse where your build tree is and select the root build tree directory. Keep copy projects into workspace unchecked."
echo "   4. You get a fully functional eclipse project"
echo


