#ifndef TEST_DETACHED_TEST
#define TEST_XMLSIGNEDTEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/DetachedSignature.hxx>
#include <System/Security/OpenSSLSecurity.hxx>
#include <System/Security/XmlSecurityC.hxx>
#include <System/Encoding/Base64Encoder.h>
#include <System/IO/File.h>
#include <tests/StoreMockFile.hxx>
#include <tests/MockFile.hxx>

using namespace Smartmatic::System;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Encoding;
using namespace Smartmatic::System::Security;

static std::string correctDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#rsa-sha1\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>5fpE8rMcH7VTtgIec2DQfV2R/14=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>Qi/6sqoGZ+VsMeHhxzAK+WcGfZM=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>jOPm5E04LQnMZOPePSHUuVOEtAw=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>e/mTz43sJla4EqE9uHVTzZv4ssY=</DigestValue></Reference></SignedInfo><SignatureValue>ncV4XKfUxNnP9QUind32fwDyn1V9hyxSawJNFIfY6jMXSFevVcGdM/hEKaD6GUlX7f1V0goxEoOz" \
        "OpoLGQIkGEXimttipPeNHcXiUpKBuvpNjDjhNy+LH3dK0qClL/qRfGc/Y/mXfM1aZYcUGvbYeOFJ" \
        "2C00h8VUR9IPYnwfcmw=</SignatureValue><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUxETAPBgNVBAgT" \
        "CEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNV" \
        "BAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNVBAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUz" \
        "WhgPMjExMjA3MjQxNTEyNTNaMIGJMQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzAR" \
        "BgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMT" \
        "BlVzZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZIhvcN" \
        "AQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpDS2uI12SNIyNQqszPXF51" \
        "euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFuHFh0uhqArqL6LoKc2zs5xTbrl+ueyzZk" \
        "COLdmoolgaSzas+qbLGeO86ub5qXROTwxj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZI" \
        "AYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAe" \
        "jEx7mR5gIRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG9w0B" \
        "AQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgwslWSXI+SnVtiKPOS" \
        "W75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+xjiljHFMKWIshq9FCYPoYzhAhW+d" \
        "X9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string incorrectDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#rsa-sha1\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>5fpE8rMcH7VTtgIec2DQfV2R/14=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>Qi/6sqoGZ+VsMeHhxzAK+WcGfZM=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>jOPm5E04LQnMZOPePSHUuVOEtAw=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>e/mTz43sJla4EqE9uHVTzZv4ssY=</DigestValue></Reference></SignedInfo><SignatureValue>ncV4XKfUxNnP9QUind32fwDyn1V9hyxSawJNFIfY6jMXSFevVcGdM/hEKaD6GUlX7f1V0goxEoOz" \
        "OpoLGQIkGEXimttipPeNHcXiUpKBuvpNjDjhNy+LH3dK0qClL/qRfGc/Y/mXfM1aZYcUGvbYeOFJ" \
        "2C00h8VUR9IPYnwfcmw=</SignatureValue><KeyInfo></KeyInfo><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUxETAPBgNVBAgT" \
        "CEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNV" \
        "BAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNVBAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUz" \
        "WhgPMjExMjA3MjQxNTEyNTNaMIGJMQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzAR" \
        "BgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMT" \
        "BlVzZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZIhvcN" \
        "AQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpDS2uI12SNIyNQqszPXF51" \
        "euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFuHFh0uhqArqL6LoKc2zs5xTbrl+ueyzZk" \
        "COLdmoolgaSzas+qbLGeO86ub5qXROTwxj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZI" \
        "AYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAe" \
        "jEx7mR5gIRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG9w0B" \
        "AQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgwslWSXI+SnVtiKPOS" \
        "W75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+xjiljHFMKWIshq9FCYPoYzhAhW+d" \
        "X9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string URIEmptyDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#rsa-sha1\"/><Reference URI=\"\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>5fpE8rMcH7VTtgIec2DQfV2R/14=</DigestValue></Reference>"
        "</SignedInfo><SignatureValue>ncV4XKfUxNnP9QUind32fwDyn1V9hyxSawJNFIfY6jMXSFevVcGdM/hEKaD6GUlX7f1V0goxEoOz" \
        "OpoLGQIkGEXimttipPeNHcXiUpKBuvpNjDjhNy+LH3dK0qClL/qRfGc/Y/mXfM1aZYcUGvbYeOFJ" \
        "2C00h8VUR9IPYnwfcmw=</SignatureValue><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUxETAPBgNVBAgT" \
        "CEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNV" \
        "BAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNVBAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUz" \
        "WhgPMjExMjA3MjQxNTEyNTNaMIGJMQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzAR" \
        "BgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMT" \
        "BlVzZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZIhvcN" \
        "AQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpDS2uI12SNIyNQqszPXF51" \
        "euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFuHFh0uhqArqL6LoKc2zs5xTbrl+ueyzZk" \
        "COLdmoolgaSzas+qbLGeO86ub5qXROTwxj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZI" \
        "AYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAe" \
        "jEx7mR5gIRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG9w0B" \
        "AQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgwslWSXI+SnVtiKPOS" \
        "W75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+xjiljHFMKWIshq9FCYPoYzhAhW+d" \
        "X9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string changeDigestValueDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#rsa-sha1\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>4fpE8rMcH7VTtgIec2DQfV2R/14=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>Qi/6sqoGZ+VsMeHhxzAK+WcGfZM=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>jOPm5E04LQnMZOPePSHUuVOEtAw=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>e/mTz43sJla4EqE9uHVTzZv4ssY=</DigestValue></Reference></SignedInfo><SignatureValue>ncV4XKfUxNnP9QUind32fwDyn1V9hyxSawJNFIfY6jMXSFevVcGdM/hEKaD6GUlX7f1V0goxEoOz" \
        "OpoLGQIkGEXimttipPeNHcXiUpKBuvpNjDjhNy+LH3dK0qClL/qRfGc/Y/mXfM1aZYcUGvbYeOFJ" \
        "2C00h8VUR9IPYnwfcmw=</SignatureValue><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUxETAPBgNVBAgT" \
        "CEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNV" \
        "BAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNVBAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUz" \
        "WhgPMjExMjA3MjQxNTEyNTNaMIGJMQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzAR" \
        "BgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMT" \
        "BlVzZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZIhvcN" \
        "AQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpDS2uI12SNIyNQqszPXF51" \
        "euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFuHFh0uhqArqL6LoKc2zs5xTbrl+ueyzZk" \
        "COLdmoolgaSzas+qbLGeO86ub5qXROTwxj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZI" \
        "AYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAe" \
        "jEx7mR5gIRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG9w0B" \
        "AQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgwslWSXI+SnVtiKPOS" \
        "W75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+xjiljHFMKWIshq9FCYPoYzhAhW+d" \
        "X9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string changueSignatureValueDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#rsa-sha1\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>5fpE8rMcH7VTtgIec2DQfV2R/14=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>Qi/6sqoGZ+VsMeHhxzAK+WcGfZM=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>jOPm5E04LQnMZOPePSHUuVOEtAw=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>e/mTz43sJla4EqE9uHVTzZv4ssY=</DigestValue></Reference></SignedInfo><SignatureValue>ncV4XKfUxNnP9QUind32fwDyn1V9hyxSawJNFIfY6jMXSFevVcGdM/hEKaD6GUlX7f1V0goxEoOz" \
        "XpoLGQIkGEXimttipPeNHcXiUpKBuvpNjDjhNy+LH3dK0qClL/qRfGc/Y/mXfM1aZYcUGvbYeOFJ" \
        "2C00h8VUR9IPYnwfcmw=</SignatureValue><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUxETAPBgNVBAgT" \
        "CEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNV" \
        "BAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNVBAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUz" \
        "WhgPMjExMjA3MjQxNTEyNTNaMIGJMQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzAR" \
        "BgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMT" \
        "BlVzZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZIhvcN" \
        "AQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpDS2uI12SNIyNQqszPXF51" \
        "euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFuHFh0uhqArqL6LoKc2zs5xTbrl+ueyzZk" \
        "COLdmoolgaSzas+qbLGeO86ub5qXROTwxj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZI" \
        "AYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAe" \
        "jEx7mR5gIRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG9w0B" \
        "AQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgwslWSXI+SnVtiKPOS" \
        "W75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+xjiljHFMKWIshq9FCYPoYzhAhW+d" \
        "X9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string changueCertificateDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#rsa-sha1\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>5fpE8rMcH7VTtgIec2DQfV2R/14=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>Qi/6sqoGZ+VsMeHhxzAK+WcGfZM=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>jOPm5E04LQnMZOPePSHUuVOEtAw=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2000/09/xmldsig#sha1\"/><DigestValue>e/mTz43sJla4EqE9uHVTzZv4ssY=</DigestValue></Reference></SignedInfo><SignatureValue>ncV4XKfUxNnP9QUind32fwDyn1V9hyxSawJNFIfY6jMXSFevVcGdM/hEKaD6GUlX7f1V0goxEoOz" \
        "OpoLGQIkGEXimttipPeNHcXiUpKBuvpNjDjhNy+LH3dK0qClL/qRfGc/Y/mXfM1aZYcUGvbYeOFJ" \
        "2C00h8VUR9IPYnwfcmw=</SignatureValue><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUxETAPBgNVBAgT" \
        "XEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNV" \
        "BAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNVBAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUz" \
        "WhgPMjExMjA3MjQxNTEyNTNaMIGJMQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzAR" \
        "BgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMT" \
        "BlVzZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZIhvcN" \
        "AQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpDS2uI12SNIyNQqszPXF51" \
        "euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFuHFh0uhqArqL6LoKc2zs5xTbrl+ueyzZk" \
        "COLdmoolgaSzas+qbLGeO86ub5qXROTwxj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZI" \
        "AYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAe" \
        "jEx7mR5gIRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG9w0B" \
        "AQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgwslWSXI+SnVtiKPOS" \
        "W75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+xjiljHFMKWIshq9FCYPoYzhAhW+d" \
        "X9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string b64fileOne = "MQo=";

static std::string b64fileTwo = "ZG9zCg==";

static std::string b64fileThree = "cGFzc3dvcmRwa2NzMTIK";

static std::string b64fileFour = "MIIKcQIBAzCCCjcGCSqGSIb3DQEHAaCCCigEggokMIIKIDCCBx8GCSqGSIb3DQEH" \
                                 "BqCCBxAwggcMAgEAMIIHBQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQI1DfW" \
                                 "c2iuUWECAggAgIIG2Gtew4WNTrGALpGtMr+FcKaqpfreGmx3AmIlHXIMdb4GoPXr" \
                                 "aGg4+ocpxetpGMw5TUkvCziQpXQ/8DPZFzzf0R4rWDKTdrb9Z7o8gD9tOsQD1JRT" \
                                 "tnexdfL7aCTlOcDbaVP3u3ZpwDuTgKyLmO0ReXsOmTOBmv3v9aZQ88KxM9QcIf65" \
                                 "Y3x+6usRE42OLWOxg2Tjm5DxrxLIB/nAZCSkRcnOEBgBQHr1BShNyqqn81ESmYlj" \
                                 "/XjTlaRMtCFsAiJKVuzke9sVaISrqNN038jMFlRlH3BRabdYwrJXu6uyOfPUl9cS" \
                                 "FE/cZ5ivANwierLwMDRC/UDQkSSdIqc3YBtbUr03xxpD3bIYWDdzdBqaNGVjXto8" \
                                 "ZpTBknyb4GKqHqGLvN7y6xRS48JR/Z4VlA52vGTsJQy+gwK/ti5nhGY2ex0hmrLe" \
                                 "hC7vi3s+WUkUBII9UQpebRTaVnagS0kC8/DJCn8R0W2/07m5LXFhVrDw5GCFF6xY" \
                                 "b+59LGhVK/RnIDgOevLg4eTAAmGmthlTm1TxVtsBNblXjNbLLte93Eb83Qr3Kvzy" \
                                 "Q/2KJcEUkCEnRaYHYcN3ItZUMRcDMOPGe3BzsM4A7qDfJCNOn8mWghS4fV3Wfqjg" \
                                 "d0TYrj2wMvoooG9v2n6z4nFmbEhXVq5AQPdeb/vQWdZabzOSyDf2oUmU8IpDsnCj" \
                                 "SgOt1Uuh31CyNM2nY3mWUEkAqOYeL4QcLVeSzxkubEA6OKeMCK69fpjvW0/YdCyA" \
                                 "aliuhV9N3iiAQsFv8eje+GK9AZtf6DHoUaJtlIrsIKvrIk4SFjPKz6AkwUKBvp2c" \
                                 "V0lGxqdSmgiJ8JMfmgazQV6gi6ZqiYVl1B4dHjXZ/YornJmWgtZiVRQcDq2tRX8x" \
                                 "FEW6oYEG/Emy8IieeaBxQ88XYL1xEW0UUsRe1mtw5FaiH5WHCG1jUaVMaed7LOC1" \
                                 "ap0O7arxIqz7DFQE7e+wBxGisTpvutM0Xs8DXI6R63fBepBBidLWTeFQSTLEFW01" \
                                 "JKZ+fJUwASA5q6wgdl/bf1yrFzl1pld+JEWzkd2eCu9ubezdVn2OhY9MlwB64aCx" \
                                 "PooOp9eZmt+bYD38fIVCjDomsqLvoHm6T6bCHj4Y8I/nl67wX99q36U6c0WHGKpY" \
                                 "71o4DW77ejtiVA59K4j8QklVZpTM+FmjuyrTUHiOF8Lb37GZL8hdI/zCHoUrIG15" \
                                 "Xvr/9Bm3nkjPc6IY1i9qwHeUtXaxFDFXzAjzqcaEvIx56O6EvAuyrT6rcdnVV98P" \
                                 "BvCcxW65fxW9Yq7KsbpB/DasF1TD8ENWowW914qfblyVglYGi8sxo5M8atTxmL2k" \
                                 "lGwsL9iEJzwbXBmp12dHdjkKKwMI01HW73tQsDtVeE76gWe0WLObsxfQIDG2Bol8" \
                                 "zc+SW356ayEOQ04QZNQQ0A3mCVtNBcEKZpHdY+JxNcb+j47nxmEvbB00M/KR6QXd" \
                                 "DcGhOPQSDLvrGl9iC79hQuWBUoxVuAX2J8adKlKl5i+elBbw4Ow5oDpirdQERdZW" \
                                 "oqk6ioiJbvvf6FvdLiQnYS/tTEiO/+6dz+Lpu6Nv2bG9i6bgWHWk++PEWRlUutKl" \
                                 "sGItFpmQUYZ5/sH1bExedgLfvFIJ+UKBrOLNLgmTmIvFoxoMcRg5zacJhyOOvuZC" \
                                 "4Tv19spKku2cHEeLXNl42ZQWOwoBQvVtKcFWPxm4ZY9l+j6Z4QdlRDoePRt6CyGO" \
                                 "3C2qexsJ6y2bffFkIxiEc8/I48FSo4ilVNrS3hVIT8pwLZbCviBmTug4DsS617kb" \
                                 "UHp4vznGosCi+ZrOwR/rL+5WtRrXbCWnqwrVImAClF8fCehJ6QAxOKrOioKXT0C5" \
                                 "OKxWXmOR9eADSG+wPD88DBDxSgLkZtlsWBTkSoW3E5+ZxI2i/JuKrPohYtWEyUK5" \
                                 "5/fBOA1nuiCHQjw90tNwtynFQzOtDZtMO2F062c3iun7bCP+0f82SfGTI/y1r9Bm" \
                                 "XwoT1NKMY5cUlnlg69jy0prxYi+92/A6uSYMNV8V+gikGp+ItTzmWqIktxGz54Yt" \
                                 "nQDtg0ncqko59pjf294rFAaHAS8iug4vt2ZwoG8nbK0Jq1GJuscsuJhWG69Fh2XO" \
                                 "OWAQYfRa+IIXiC61woRytU9kKrmKAdW8xuWONtdjNKOh88wvvYLypPB7H/5ueD8c" \
                                 "6qfuJy07YDXhlf+WTv9CpsUGKTBeBPTgOj+LGig70SZopOTeyL6m6fjkFFK2DZD6" \
                                 "MKPrAu0CVDzA3+o0QPdZox1rfd0oYcIl+5oKA9nYl1rG13pullDdy93KNGZZhiky" \
                                 "dKOtrGt7WTY7o8/BRNxAzAGlI8t77A22KqSHAAXCy0rkkTwRGjCCAvkGCSqGSIb3" \
                                 "DQEHAaCCAuoEggLmMIIC4jCCAt4GCyqGSIb3DQEMCgECoIICpjCCAqIwHAYKKoZI" \
                                 "hvcNAQwBAzAOBAh/liYliUlRvwICCAAEggKAZDhx2m31ZDk0xsQGXbS7qrx7DFkM" \
                                 "xbbgK9agDLJ0zQ3StaGo05DLdqmD6y3erCgrT4FxLxwvjxr9q08bSOu5ZvANYlBC" \
                                 "p8GUcRhDmswhkGPBmLh7bbVU6mFck02pr1kntm1qFr05JYZ+DFIYS+hwoPv0DU8m" \
                                 "C7VCYV/crUHrfjBow5i8XKngd6q9UwxbrkLlDhRgmHwlAlWXg767C+Ds8TYe5wgr" \
                                 "ln5wft7R757vITytvQC0Ul3ELdAj+7jyiifsuLwG/BgJT82BU6M5NtMG9pJKafpj" \
                                 "3RSIqqfrDz9TppG4AcoisFjUj67ZES2Y1uUEhW7V1M8elbVl1zsv9GQFr90IP82o" \
                                 "rb+UVpmUoR49f25Eqw9HO48cHvqnjHwFDc+0AQiDmQNQHanp+H98hmQA0Z6qvaEE" \
                                 "fKT8ITn8daUC7yP7zLefAauTnLlOw12G6YUIHD0CKt3uR3+OwifkHd2nVRKtjBqG" \
                                 "7oXZiX5xaJ159ieiKZ+wXQGWXjyIIowHWhOnAuzMKV5uEm44KPKRWyQDNceR66mq" \
                                 "tPPLiYXHX7WIJJh/ubazZ0Lh9zp5wTAefcDHhOjAlJr4K6Blb3fBOhtlqMQNK3A+" \
                                 "IJqHJgcEvL2HN4n4CysVFrw+YG76snA2V1GttwUl95wpw1sgne5p5MR6s8XtYWf3" \
                                 "Vbx6tELh8ivEWhqy0qHV+Yq2P6WmpTX0QBSieWJ4uCeTcEWiko1jvdTAIb1W1M8N" \
                                 "oPStPiOBHFQ2r/wzo7co/30Z7e1F2ZSqMWfzXGx9cXzEu4RipIjiYTRxl0galgXM" \
                                 "T42xlJp8Ut/36k0DYFU12Uzkj3Mw1Z89d5GbpmyIDmaSitIJ4w+2gM7cFzElMCMG" \
                                 "CSqGSIb3DQEJFTEWBBQJ8cvFVKweYsoJq7FTQU2QoxBKaTAxMCEwCQYFKw4DAhoF" \
                                 "AAQULiJWJiOVenea6+yEhex0GcuehmgECHH2ajsukIsvAgIIAA==";

class DetachedTest : public CPPUNIT_NS::TestFixture
{
    private:

        DetachedSignature * manager;

    public:

        DetachedTest()
        {
            manager = NULL;
        }

        void setUp()
        {
            manager = new DetachedSignature();

            Smartmatic::System::Security::OpenSSLSecurity::init();
            Smartmatic::System::Security::XmlSecurityC::init();
        }

        void tearDown()
        {
            if ( manager )
            {
                delete manager;
                manager = NULL;
            }

            Smartmatic::System::Security::OpenSSLSecurity::clear();
            Smartmatic::System::Security::XmlSecurityC::clear();
        }

        void testVerifyBuffer ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( true == result );
        }

        void testVerifyBufferWithIncorrectInputFile ()
        {
            SafeBuffer buffer ( incorrectDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferWithEmptyInputFile ()
        {
            SafeBuffer buffer;

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferChangeDigestValue ()
        {
            SafeBuffer buffer ( changeDigestValueDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferChangeSignatureValue ()
        {
            SafeBuffer buffer ( changueSignatureValueDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferChangeCertificateValue ()
        {
            SafeBuffer buffer ( changueCertificateDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferURIEmpty ()
        {
            SafeBuffer buffer ( URIEmptyDetachedFile );

            MockFile file;
            File::getInstance ( &file );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &file );

            openFileToBuffer_mock
            .expects ( MOCKPP_NS::never() );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( true == result );

            file.verify();
        }

        void testVerifyBufferFirstEmpty ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferLastEmpty ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer (), true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferFirstChangue ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            fileOne.push_back ( 0x00 );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferLastChangue ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            fileFour.push_back ( 0x00 );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferMissingFile ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, false ) );

            bool result;

            result = manager->verifyBuffer ( buffer, "base" );

            CPPUNIT_ASSERT ( false == result );
        }

        CPPUNIT_TEST_SUITE ( DetachedTest );

        CPPUNIT_TEST ( testVerifyBuffer );
        CPPUNIT_TEST ( testVerifyBufferWithIncorrectInputFile );
        CPPUNIT_TEST ( testVerifyBufferWithEmptyInputFile );
        CPPUNIT_TEST ( testVerifyBufferChangeDigestValue );
        CPPUNIT_TEST ( testVerifyBufferChangeSignatureValue );
        CPPUNIT_TEST ( testVerifyBufferChangeCertificateValue );
        CPPUNIT_TEST ( testVerifyBufferURIEmpty );
        CPPUNIT_TEST ( testVerifyBufferFirstEmpty );
        CPPUNIT_TEST ( testVerifyBufferLastEmpty );
        CPPUNIT_TEST ( testVerifyBufferFirstChangue );
        CPPUNIT_TEST ( testVerifyBufferLastChangue );
        CPPUNIT_TEST ( testVerifyBufferMissingFile );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_DETACHED_TEST */
