#!/bin/bash -e
#
# File: smtt-create-disk.sh
#
# This script compiles the third-party code and configurations
#
# Date: Tue 22 jun 2017 18:45:23
# Author: gustavo.garcia
#
# Revision 1
#
# Copyright 2017 Smartmatic Corp. All Rights Reserved.
#
# Confidential Information of Smartmatic Labs. Not for disclosure or distribution
# prior written consent. This software contains code, techniques and know-how which
# is confidential and proprietary to Smartmatic.
#
# Use of this software is subject to the terms of an end user license agreement.

###############
#  VARIABLES  #
###############

HELP="Wrong usage\n
Usage: $0 USB_DEVICE\n
where:\n
- USB_DEVICE: Device to format. i.e. /dev/sdb\n"

##########################
#  VALIDATING ARGUMENTS  #
##########################

if [ ${#} -lt 1 ]
then
    echo -e ${HELP}
    exit 1
fi

EFI_PKG=$(dpkg -s grub-efi-amd64 2>/dev/null|wc -l)
if [ $EFI_PKG -eq 0 ]
then
    echo -e "Error: Please install grub-efi-amd64. i.e. apt-get install grub-efi-amd64\n"
    exit 1
fi

GRUB_PKG=$(dpkg -s grub2-common 2>/dev/null|wc -l)
if [ $GRUB_PKG -eq 0 ]
then
    echo -e "Error: Please install grub2-common. i.e. apt-get install grub2-common\n"
    exit 1
fi

DISK=$1
FATDISK="$DISK""1"
EFIDISK="$DISK""2"
EXT3DISK="$DISK""3"
MOUNT_PATH="/mnt/chroot_ext3"
MOUNT_PATH_VFAT="/mnt/data_vfat"
MOUNT_PATH_EFI="/mnt/efi_vfat"

###########
#  BEGIN  #
###########

echo "I: Unmounting all devices in ${DISK}"
mount |grep $DISK|awk '{print $3}'|while read -r line ; do umount $line; done

echo "I: Starting formatting with fdisk..."
fdisk $DISK <<EOF
o
n
p
1
2048
+2097152
n
p
2

+204800
n
p
3


a
3
t
1
b
t
2
ef
w
EOF

mkfs.vfat $FATDISK
mkfs.vfat $EFIDISK
mkfs.ext3 $EXT3DISK
sync

mkdir -p $MOUNT_PATH
mkdir -p $MOUNT_PATH_VFAT
mkdir -p $MOUNT_PATH_EFI

mount $EXT3DISK $MOUNT_PATH
mount $FATDISK  $MOUNT_PATH_VFAT
mount $EFIDISK  $MOUNT_PATH_EFI

echo "I: Installing grub..."
mkdir $MOUNT_PATH/boot
grub-install --target=x86_64-efi --efi-directory=$MOUNT_PATH_EFI --boot-directory=$MOUNT_PATH/boot --removable --recheck $DISK
grub-install --target=i386-pc --boot-directory=$MOUNT_PATH/boot --recheck $DISK


mkdir $MOUNT_PATH_EFI/EFI/ubuntu
mv $MOUNT_PATH_EFI/EFI/BOOT/BOOTX64.EFI $MOUNT_PATH_EFI/EFI/ubuntu/grubx64.efi
rm -r $MOUNT_PATH_EFI/EFI/BOOT

umount $MOUNT_PATH
umount $MOUNT_PATH_VFAT
umount $MOUNT_PATH_EFI

echo -n "I: Removing dirty bit from FAT partition... "
fsck.fat $FATDISK -a
sync

echo -n "I: Done"

#########
#  END  #
#########
