#!/bin/bash
#
# File: smtt-generate-rootfs.sh
# USAGE: Generate root fileSystem.
# EXAMPLE: ./smtt-generate-rootfs.sh <output_path> <chrootFolder_path>
#
# This script generates the base OS for the follwing devices:
# SAES3370, PM-Netbook, VIU-805.
#
# Date: Tue 22 jun 2017 18:45:23
# Author: gustavo.garcia
#
# Copyright 2017 Smartmatic Corp. All Rights Reserved.
# Confidential Information of Smartmatic Labs. Not for disclosure or distribution
# prior written consent. This software contains code, techniques and know-how which
# is confidential and proprietary to Smartmatic.
# Use of this software is subject to the terms of an end user license agreement.

OUTPUTFOLDER=$1/OS
CHROOTFOLDER=$2
OS_BUILDER=$(dirname $(readlink -f $0))/../
SMTT_PACKAGES="compiled-pkgs"
VERSION=$(cat ${OS_BUILDER}/VERSION)
USERNAME="saes"
HOSTNAME="Bevoting"
USER_PASSWORD='$6$Jwb.uHsdHe$bBMu.h7BtrtqGQY3g3xeT9Xk/GcZdfTKz.9DuA9nI6kiV8q5l7PpeUF5s8dxYgyOTV9ENWXvcHvlwn5Wfg30U0'
KERNEL_V1="3.13.0-119"
KERNEL_V2="4.10.0-32"

if [ -z "${OUTPUTFOLDER}" ]; then
   echo "Please define the OUTPUT folder"
   exit
fi

if [ -z "${CHROOTFOLDER}" ]; then
   echo "Please define the chrootbase folder: This can be created by using debootstrap"
   exit
fi

rm -rf ${OUTPUTFOLDER}
mkdir -p "${OUTPUTFOLDER}"/{boot/grub/i386-pc,boot/grub/x86_64-efi,live}

clean_chroot()
{
    find ${CHROOTFOLDER}/usr/share/doc -depth -type f ! -name copyright | xargs rm
    find ${CHROOTFOLDER}/usr/share/doc -empty | xargs rmdir
    rm -rf ${CHROOTFOLDER}/usr/share/man/* ${CHROOTFOLDER}/usr/share/groff/* ${CHROOTFOLDER}/usr/share/info/*
    rm -rf ${CHROOTFOLDER}/usr/share/lintian/* ${CHROOTFOLDER}/usr/share/linda/* ${CHROOTFOLDER}/var/cache/man/*
    rm -f  ${CHROOTFOLDER}/initrd.img ${CHROOTFOLDER}/vmlinuz
    rm -rf  ${CHROOTFOLDER}/root/*
    rm -rf  ${CHROOTFOLDER}/tmp/*
    rm -rf ${CHROOTFOLDER}/var/lib/apt/lists/*
    rm -rf ${CHROOTFOLDER}/etc/apt/sources.list.d/*
    chroot ${CHROOTFOLDER} apt-get clean
}

mount_devices()
{
    echo "I: Mounting dev, sys and proc filesystems"
    mount --bind /dev/ ${CHROOTFOLDER}/dev
    mount -t proc proc ${CHROOTFOLDER}/proc
    mount -t sysfs sysfs ${CHROOTFOLDER}/sys
}

umount_devices()
{
   echo "I: Umounting dev-sys-proc folders"
   sync
   umount -l ${CHROOTFOLDER}/dev
  umount ${CHROOTFOLDER}/proc
   umount ${CHROOTFOLDER}/sys
}

save_squash_and_kernel()
{
    umount_devices
    echo "I: Generating squashfs and others artifacts"
    clean_chroot
    mksquashfs ${CHROOTFOLDER} ${OUTPUTFOLDER}/live/$1 -noappend -e boot
    cp ${CHROOTFOLDER}/boot/vmlinuz-* ${OUTPUTFOLDER}/live/
}

generate_final_artifact()
{
    echo "I: Getting OS_builder artifacts"
    cp $OS_BUILDER/boot/{grub.cfg,splash-*} ${OUTPUTFOLDER}/boot/grub/
    cp $OS_BUILDER/boot/host_bridge.mod ${OUTPUTFOLDER}/boot/grub/i386-pc
    cp $OS_BUILDER/boot/host_bridge_efi.mod ${OUTPUTFOLDER}/boot/grub/x86_64-efi/host_bridge.mod
    cp $OS_BUILDER/boot/initrd-pm.gz ${OUTPUTFOLDER}/live/initrd-pm
    cp $OS_BUILDER/boot/initrd-vm.gz ${OUTPUTFOLDER}/live/initrd-vm
    cp $OS_BUILDER/boot/initrd-4.10.0-32.gz ${OUTPUTFOLDER}/live/initrd-4.10.0-32
    echo "I: Generating OS.tar file"
    cd ${OUTPUTFOLDER}/../
    tar -czvf OS.tar.gz OS
    rm -r OS
    md5sum OS.tar.gz > md5sum.txt
}


#mkdir -p ${CHROOTFOLDER}
#debootstrap --arch=i386 --variant=minbase trusty ${CHROOTFOLDER} http://archive.ubuntu.com/ubuntu/

# Set OS Version Number
mkdir ${CHROOTFOLDER}/etc/smtt
echo 'OS Base: Ubuntu Trusty 14.04' > ${CHROOTFOLDER}/etc/smtt/smtt-os-version
echo "Version: ${VERSION}" >> ${CHROOTFOLDER}/etc/smtt/smtt-os-version

echo "${HOSTNAME}" > ${CHROOTFOLDER}/etc/hostname
echo "127.0.1.1    ${HOSTNAME}" >> ${CHROOTFOLDER}/etc/hosts

echo 'deb http://us.archive.ubuntu.com/ubuntu trusty main restricted universe'          > ${CHROOTFOLDER}/etc/apt/sources.list.d/smartmatic-trusty.list
echo 'deb http://us.archive.ubuntu.com/ubuntu trusty-updates main restricted universe' >> ${CHROOTFOLDER}/etc/apt/sources.list.d/smartmatic-trusty.list
echo 'deb http://security.ubuntu.com/ubuntu trusty-security main restricted universe'  >> ${CHROOTFOLDER}/etc/apt/sources.list.d/smartmatic-trusty.list
echo 'deb http://cloudci.esbu.smartmatic.net/apt_smtt trusty main'                     >> ${CHROOTFOLDER}/etc/apt/sources.list.d/smartmatic-trusty.list

wget -O- http://cloudci.esbu.smartmatic.net/apt_smtt/smtt-packages.reprepro.key > ${CHROOTFOLDER}/root/smtt-packages.reprepro.key
chroot ${CHROOTFOLDER} apt-key add /root/smtt-packages.reprepro.key

mount_devices

chroot ${CHROOTFOLDER} apt update
chroot ${CHROOTFOLDER} locale-gen en_US.UTF-8
chroot ${CHROOTFOLDER} locale-gen fr_BE.UTF-8
chroot ${CHROOTFOLDER} locale-gen fr_FR.UTF-8
chroot ${CHROOTFOLDER} locale-gen nl_NL.UTF-8
chroot ${CHROOTFOLDER} locale-gen nl_BE.UTF-8
chroot ${CHROOTFOLDER} locale-gen de_BE.UTF-8
chroot ${CHROOTFOLDER} locale-gen de_DE.UTF-8
chroot ${CHROOTFOLDER} dpkg-reconfigure locales

echo "I: Installing OS Dependencies"
chroot ${CHROOTFOLDER} apt-get install -y --no-install-recommends \
xserver-xorg \
xserver-xorg-core \
xserver-xorg-video-fbdev \
x11-xserver-utils \
xinit \
openbox \
xterm \
udevil \
inputattach \
libpcsclite1 \
libccid \
pcscd \
cups \
libqrencode3 \
libb64-0d \
libgtkmm-2.4-1c2a \
libxerces-c3.1 \
liblog4cxx10 \
usbutils \
pciutils \
beep \
alsa-utils \
fop \
lightdm \
python-crcmod \
python-serial \
software-properties-common \
scrot \
pngcheck \
xloadimage \
sudo \
gvfs \
dbus-x11 \
policykit-1 \
libao-common \
libao4 \
gtk2-engines-murrine

echo "I: Creating $USERNAME user"
chroot ${CHROOTFOLDER} useradd -m -p $USER_PASSWORD -s /bin/bash $USERNAME
chroot ${CHROOTFOLDER} usermod -a -G sudo,lp,lpadmin,audio,plugdev,dialout $USERNAME


echo "I: Installing Security Packages"
chroot ${CHROOTFOLDER} add-apt-repository ppa:0k53d-karl-f830m/openssl
chroot ${CHROOTFOLDER} apt update
chroot ${CHROOTFOLDER} apt-get install libxml-security

echo "I: Upgrading distro"
chroot ${CHROOTFOLDER} apt-get dist-upgrade -y

echo "I: Installing Kernel"
chroot ${CHROOTFOLDER} apt-get install -y --no-install-recommends linux-image-${KERNEL_V1}-generic linux-image-extra-${KERNEL_V1}-generic live-boot

./scripts/smtt-compile-packages.sh
if [ "$?" = "1" ]; then
   echo "Error: smtt-compile-packages.sh"
   umount_devices
   exit 1
fi

cp ${SMTT_PACKAGES}/*.deb ${CHROOTFOLDER}/root/

echo 'xset -dpms s off'                       >> ${CHROOTFOLDER}/etc/xdg/openbox/autostart
echo 'xrandr --output LVDS-1 --rotate left'   >> ${CHROOTFOLDER}/etc/xdg/openbox/autostart
echo 'smtt-load-election &'                   >> ${CHROOTFOLDER}/etc/xdg/openbox/autostart

chroot ${CHROOTFOLDER} update-rc.d ondemand disable

echo "manual" > ${CHROOTFOLDER}/etc/init/tty1.override
echo "manual" > ${CHROOTFOLDER}/etc/init/tty2.override
echo "manual" > ${CHROOTFOLDER}/etc/init/tty3.override
echo "manual" > ${CHROOTFOLDER}/etc/init/tty4.override
echo "manual" > ${CHROOTFOLDER}/etc/init/tty5.override
echo "manual" > ${CHROOTFOLDER}/etc/init/tty6.override

echo "I: Creating links for audio voting libraries support"
echo "/usr/lib/ve">>${CHROOTFOLDER}/etc/ld.so.conf.d/libc.conf
chroot ${CHROOTFOLDER} ldconfig

sed -i 's/blacklist snd_pcsp/#&/' ${CHROOTFOLDER}/etc/modprobe.d/blacklist.conf
echo 'options snd-pcsp index=-2' > ${CHROOTFOLDER}/etc/modprobe.d/alsa-base.conf

echo 'Xft.autohint: 0'          > ${CHROOTFOLDER}/etc/X11/Xresources/xft
echo 'Xft.antialias: 1'        >> ${CHROOTFOLDER}/etc/X11/Xresources/xft
echo 'Xft.hinting: true'       >> ${CHROOTFOLDER}/etc/X11/Xresources/xft
echo 'Xft.hintstyle: hintnone' >> ${CHROOTFOLDER}/etc/X11/Xresources/xft

cat <<EOT >> ${CHROOTFOLDER}/root/run.sh
#!/bin/sh -e
rm /root/*a4500*.deb 
dpkg -i --force-overwrite /root/*.deb
EOT
if [ "$?" = "1" ]; then
   echo "Error: dpkg failed during installation"
   umount_devices
   exit 1
fi

chroot ${CHROOTFOLDER} sh /root/run.sh
chroot ${CHROOTFOLDER} update-alternatives --install /lib/plymouth/themes/default.plymouth default.plymouth /lib/plymouth/themes/smartmatic/smartmatic.plymouth 100
chroot ${CHROOTFOLDER} update-alternatives --config default.plymouth

chroot ${CHROOTFOLDER} depmod -a ${KERNEL_V1}-generic

echo "I: Setting $USERNAME special permissions"
chroot ${CHROOTFOLDER} chmod +s /sbin/poweroff
chroot ${CHROOTFOLDER} chmod +s /bin/date
chroot ${CHROOTFOLDER} chown $USERNAME.$USERNAME -R /etc/penmount

save_squash_and_kernel filesystem-v${KERNEL_V1}.squashfs

echo "I: Updating Kernel for VIU-805"
mount_devices
echo 'deb http://security.ubuntu.com/ubuntu xenial-security main' >> ${CHROOTFOLDER}/etc/apt/sources.list.d/smartmatic-trusty.list
echo 'deb http://us.archive.ubuntu.com/ubuntu trusty-updates main restricted universe' >> ${CHROOTFOLDER}/etc/apt/sources.list.d/smartmatic-trusty.list
chroot ${CHROOTFOLDER} apt update
chroot ${CHROOTFOLDER} apt-get install -y --no-install-recommends linux-image-${KERNEL_V2}-generic linux-image-extra-${KERNEL_V2}-generic linux-firmware
chroot ${CHROOTFOLDER} apt-get remove -y --purge linux-image-${KERNEL_V1}-generic linux-image-extra-${KERNEL_V1}-generic

echo "I: Installing configuration for packages for A4500"
sed -i s/LVDS-1/DP1/g ${CHROOTFOLDER}/etc/xdg/openbox/autostart
chroot ${CHROOTFOLDER} apt-get remove -y --purge smtt-serial-touch-calibration* smtt-os-xorg-config*
chroot ${CHROOTFOLDER} apt-get install -y --no-install-recommends xserver-xorg-video-intel
cp ${OS_BUILDER}/configuration-scripts/xorg-config-a4500/build/*.deb ${CHROOTFOLDER}/tmp/
chroot ${CHROOTFOLDER} bash -c 'dpkg -i /tmp/smtt-os-xorg-config*'

save_squash_and_kernel filesystem-v${KERNEL_V2}.squashfs
umount_devices
generate_final_artifact

echo "I:Generation Completed"

