/**
 * EncryptDecryptUtil.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.security.asymmetric;

import javax.crypto.SecretKey;

import org.apache.commons.lang.SystemUtils;

import com.smartmatic.waffle.security.dto.CipherDTO;
import com.smartmatic.waffle.security.lang.CryptographicRuntimeException;
import com.smartmatic.waffle.security.lang.CryptographicStaticException;
import com.smartmatic.waffle.security.symmetric.PoolableSymmetricCipher;

/**
 * Class that is responsible to manage encrypt/decrypt operations using a
 * symmetric cipher.
 */
public class EncryptDecryptUtil {

	/**
	 * Method used to encrypt data to be recorded in the card.
	 * 
	 * @param data
	 *            the data
	 * @param pass
	 *            the pass
	 * @return the byte[]
	 * @throws CryptographicRuntimeException
	 *             the cryptographic runtime exception
	 * @throws CryptographicStaticException
	 *             the cryptographic static exception
	 */
	public static byte[] encryptData(byte[] data, SecretKey pass)
			throws CryptographicRuntimeException, CryptographicStaticException {
		PoolableSymmetricCipher cipher = new PoolableSymmetricCipher(pass);
		byte[] bytesEncrypted = cipher.encryptBytes(data);
		return bytesEncrypted;
	}

	/**
	 * Method used to encrypt data to be recorded in the card.
	 * 
	 * @param data
	 *            the data
	 * @param pass
	 *            the pass
	 * @param ivector
	 *            the ivector
	 * @return the byte[]
	 * @throws CryptographicRuntimeException
	 *             the cryptographic runtime exception
	 * @throws CryptographicStaticException
	 *             the cryptographic static exception
	 */
	public static byte[] encryptData(byte[] data, SecretKey pass, byte[] ivector)
			throws CryptographicRuntimeException, CryptographicStaticException {
		PoolableSymmetricCipher cipher = new PoolableSymmetricCipher(pass,
				ivector);

		byte[] encryptedData = cipher.encryptAndAppendIvToBytes(data);
		return encryptedData;
	}

	/**
	 * Method used to decrypt data comes from the card.
	 * 
	 * @param data
	 *            the data
	 * @param pass
	 *            the pass
	 * @return the byte[]
	 * @throws CryptographicStaticException
	 *             the cryptographic static exception
	 * @throws CryptographicRuntimeException
	 *             the cryptographic runtime exception
	 */
	public static byte[] decryptData(byte[] data, SecretKey pass)
			throws CryptographicStaticException, CryptographicRuntimeException {
		PoolableSymmetricCipher cipher = new PoolableSymmetricCipher(pass);
		byte[] bytesDecrypted = cipher.decryptBytes(data);
		return bytesDecrypted;
	}

	/**
	 * *.
	 * 
	 * @param data
	 *            the data
	 * @param pass
	 *            the pass
	 * @param iVector
	 *            the i vector
	 * @return the byte[]
	 * @throws CryptographicStaticException
	 *             the cryptographic static exception
	 * @throws CryptographicRuntimeException
	 *             the cryptographic runtime exception
	 */
	public static byte[] decryptData(byte[] data, SecretKey pass, byte[] iVector)
			throws CryptographicStaticException, CryptographicRuntimeException {
		PoolableSymmetricCipher cipher = new PoolableSymmetricCipher(pass,
				iVector);
		byte[] bytesDecrypted = cipher.decryptBytes(data);
		return bytesDecrypted;
	}

	/**
	 * Ensures that all data written to the medias is actually flushed.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	public static void flush() throws Exception {

		if (SystemUtils.IS_OS_UNIX) {
			ProcessBuilder processBuilder = new ProcessBuilder();
			processBuilder.command("sync");

			processBuilder.redirectErrorStream(true);
			Process process = processBuilder.start();
			try {
				process.waitFor();
			} finally {
				process.destroy();
			}

		}
	}

	/**
	 * Initialize DTO containing the iVector and the raw data to process.
	 * 
	 * @param iVectorLength
	 *            The initialization vector length.
	 * @param rawFileData
	 *            The raw data to process.
	 * @return
	 */
	public static CipherDTO prepareCipherDTO(Integer iVectorLength,
			byte[] rawFileData, int keyLength) {
		CipherDTO cipherDTO = new CipherDTO();
		cipherDTO.setiVector(new byte[iVectorLength]);
		cipherDTO.setCipheredData(new byte[rawFileData.length - iVectorLength]);

		System.arraycopy(rawFileData, 0, cipherDTO.getiVector(), 0,
				iVectorLength);

		System.arraycopy(rawFileData, iVectorLength,
				cipherDTO.getCipheredData(), 0, rawFileData.length
						- iVectorLength);
		return cipherDTO;
	}
}
