/*
 * Base64Encoder.java
 *
 * 1.0 (2004/12/03)
 *
 * Copyright (c) 2004 Smartmatic Intl.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and propietary information of
 * Smartmatic Intl. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Intl.
 */

package com.smartmatic.waffle.security.io;

import org.apache.commons.codec.binary.Base64;
import org.apache.commons.lang.StringUtils;

/**
 * <p>
 * Class used to handle all the transformation from and to Base64 Strings
 * </p>
 * 
 * @version 1.0
 * @author Ithamar Torres
 */

public final class Base64Encoder {

	/**
	 * <p>
	 * Method used to convert a byte array into a Base64 String
	 * </p>
	 * 
	 * @param data
	 *            byte[] The information that is required to convert into a
	 *            Base64 String
	 * @return String The result of convert the byte array received into a
	 *         Base64 String.
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 * @version 1.0 (31/03/2006)
	 */

	public static String encode(byte[] data) {
		return new String(Base64.encodeBase64(data, false));
	}

	/**
	 * <p>
	 * Method used to convert a byte array into a Base64 String. The line
	 * separator is supplied
	 * </p>
	 * 
	 * @param data
	 *            byte[] The information that is required to convert into a
	 *            Base64 String
	 * @param lineSeparator
	 *            The line separator used to write the encoded data.
	 * @return String The result of convert the byte array received into a
	 *         Base64 String.
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 * @version 1.0 (31/03/2006)
	 */

	public static String encode(byte[] data, String lineSeparator) {
		String encoded = new String(Base64.encodeBase64(data, false));

		String systemLineSeparator = System.getProperty("line.separator");
		if (!systemLineSeparator.equals(lineSeparator)) {
			encoded = StringUtils.replace(encoded, systemLineSeparator,
					lineSeparator);
		}

		return encoded;
	}

	/**
	 * <p>
	 * Method used to convert a Base64 String into the byte array that was
	 * before the transformation into a Base64 String. This operation reverts
	 * the operation of encoding a byte array into a Base64 String
	 * </p>
	 * 
	 * @param data
	 *            String The information that is required to decode
	 * @return byte[] The result of decode a Base64 String into a byte array
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 * @version 1.0 (31/03/2006)
	 */

	public static byte[] decode(String data) {
		return Base64.decodeBase64(data);
	}
}
