/**
 * SignGeneratorTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.security.sign;

import static org.junit.Assert.assertEquals;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.security.PrivateKey;
import java.security.cert.X509Certificate;

import org.apache.commons.io.FileUtils;
import org.apache.xml.security.signature.XMLSignature;
import org.junit.Before;
import org.junit.Test;

import com.smartmatic.waffle.security.asymmetric.AsymmetricKeyManager;

/**
 * Class used to test methods from SignGenerator class.
 */
public class SignGeneratorTest {

	/** PKCS12 in bytes to generate the signature. */
	byte[] PKCS12Bytes;

	/** Text to sign. */
	String textToSign;

	/** The certificate password. */
	String caPassword;

	/** The certificate alias. */
	String caAlias;

	/** Signature algorithm. */
	String signatureAlgorithm;

	/**
	 * Test SetUp method.
	 * 
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception {
		this.PKCS12Bytes = FileUtils
				.readFileToByteArray(new File(
						"test/com/smartmatic/waffle/security/test/testResources/test_cert.p12"));

		this.textToSign = FileUtils
				.readFileToString(new File(
						"test/com/smartmatic/waffle/security/test/testResources/xml_to_test_signing.xml"));

		this.caPassword = "bel2013";

		this.caAlias = "ecm";

		this.signatureAlgorithm = XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA1;
	}

	/**
	 * Method that generate signed data from file.
	 */
	@Test
	public void testSignTextGettingDataFromFile() throws Exception {

		// Arrange
		PrivateKey certificateCA = AsymmetricKeyManager.getPrivateKey(
				new ByteArrayInputStream(this.PKCS12Bytes), this.caPassword,
				this.caAlias, this.caPassword);

		X509Certificate x509cert = AsymmetricKeyManager.getCertificate(
				new ByteArrayInputStream(this.PKCS12Bytes), this.caPassword,
				this.caAlias);

		SignGenerator signGenerator = new SignGenerator(x509cert,
				certificateCA, this.signatureAlgorithm);

		StringBuilder textSigned = new StringBuilder(this.textToSign);

		signGenerator.signText(textSigned);

		// Act
		int signsChecked = SignValidator.getCertificatesValidated(textSigned
				.toString());

		// Assert
		assertEquals(signsChecked, 1);

	}
}
